@@ -1,9 +1,10 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-from __future__ import with_statement
 import ldap
 from trytond.model import ModelView, ModelSQL
 from trytond.transaction import Transaction
+from trytond.pool import Pool
+
 
 class User(ModelSQL, ModelView):
     _name = 'res.user'
@@ -43,7 +44,7 @@ class User(ModelSQL, ModelView):
         return result
 
     def _check_passwd_ldap_user(self, logins):
-        connection_obj = self.pool.get('ldap.connection')
+        connection_obj = Pool().get('ldap.connection')
         connection_ids = connection_obj.search([], limit=1)
         with Transaction().set_user(0):
             connection = connection_obj.browse(connection_ids[0])
@@ -81,7 +82,7 @@ class User(ModelSQL, ModelView):
         return super(User, self).write(ids, vals)
 
     def set_preferences(self, values, old_password=False):
-        connection_obj = self.pool.get('ldap.connection')
+        connection_obj = Pool().get('ldap.connection')
         if 'password' in values:
             connection_ids = connection_obj.search([], limit=1)
             with Transaction().set_user(0):
@@ -109,27 +110,29 @@ class User(ModelSQL, ModelView):
                 old_password=old_password)
 
     def get_login(self, login, password):
-        connection_obj = self.pool.get('ldap.connection')
+        connection_obj = Pool().get('ldap.connection')
         connection_ids = connection_obj.search([], limit=1)
         with Transaction().set_user(0):
             connection = connection_obj.browse(connection_ids[0])
         try:
-            con = ldap.initialize(connection.uri)
+            con = ldap.initialize(connection.uri or '')
             if connection.active_directory:
                 con.set_option(ldap.OPT_REFERRALS, 0)
             if connection.secure == 'tls':
                 con.start_tls_s()
             if connection.bind_dn:
-                con.simple_bind_s(connection.bind_dn, connection.bind_pass)
+                con.simple_bind_s(connection.bind_dn or '',
+                    connection.bind_pass or '')
             [(dn, attrs)] = self.ldap_search_user(login, con, connection,
                     attrs=[str(connection.auth_uid)])
-            if con.simple_bind_s(dn, password):
+            if password and con.simple_bind_s(dn, password):
                 user_id, _, _ = self._get_login(login)
                 if user_id:
                     return user_id
                 elif connection.auth_create_user:
                     user_id = self.create({
-                        'name': attrs.get(str(connection.auth_uid), [login])[0],
+                        'name': attrs.get(str(connection.auth_uid),
+                                [login])[0],
                         'login': login,
                         })
                     return user_id
